@@ -464,7 +464,21 @@ class GrafanaWtf(GrafanaEngine):
     def get_dashboard_versions(self, dashboard_id):
         # https://grafana.com/docs/http_api/dashboard_versions/
         get_dashboard_versions_path = "/dashboards/id/%s/versions" % dashboard_id
-        return self.grafana.dashboard.client.GET(get_dashboard_versions_path)
+        results = []
+        params = {}
+        while True:
+            data = self.grafana.dashboard.client.GET(get_dashboard_versions_path, params=params)
+            # Older Grafana returned a plain list.
+            if isinstance(data, list):
+                results.extend(data)
+                break
+            # Newer Grafana returns a dict with `versions` and optional `continueToken`.
+            results.extend(data.get("versions", []))
+            token = data.get("continueToken")
+            if not token:
+                break
+            params = {"continueToken": token}
+        return results
 
     def explore_datasources(self):
         # Prepare indexes, mapping dashboards by uid, datasources by name
@@ -715,10 +729,10 @@ class Indexer:
             # Datasources defined as variables.
             if "type" in node and node["type"] == "datasource":
                 values = to_list(node.get("current", {}).get("value"))
-                for ds_uid in values:
-                    datasource = self.datasource_by_uid.get(ds_uid)
+                for ds_name in values:
+                    datasource = self.datasource_by_name.get(ds_name)
                     if datasource is None:
-                        log.warning(f"Data source '{ds_uid}' not found")
+                        log.warning(f"Data source '{ds_name}' not found")
                         continue
                     ds = dict(
                         type=datasource.get("type"),
